import { StyleSheet } from 'react-native';
import { getThemeProperty, createSpacingStyles, createBorderWidthStyles, createBorderColorStyles, createBorderRadiusStyles, getThemeFontFamily, getFontWeight, getThemeColor } from '../../theme/theme.service';
/**
 * computed style
 *
 * @param theme
 * @param props
 */
export const getStyle = (theme, props) => {
  var _props$textShadowOffs, _props$textShadowOffs2, _props$textShadowOffs3, _props$textShadowOffs4;
  const computedStyle = {};
  computedStyle.text = {
    height: props.h,
    width: props.w,
    minHeight: props.minH,
    minWidth: props.minW,
    maxHeight: props.maxH,
    maxWidth: props.maxW,
    flex: props.flex,
    backgroundColor: getThemeColor(theme.colors, props.bg),
    overflow: props.overflow || 'hidden',
    opacity: props.opacity,
    textDecorationLine: props.textDecorLine || props.textDecorationLine,
    textDecorationStyle: props.textDecorStyle || props.textDecorationStyle,
    letterSpacing: props.letterSpacing,
    fontStyle: props.fontStyle,
    textAlignVertical: props.textAlignVertical,
    lineHeight: props.lineHeight,
    color: getThemeColor(theme.colors, props.color),
    fontSize: getThemeProperty(theme.fontSize, props.fontSize),
    textAlign: props.textAlign,
    textTransform: props.textTransform,
    textDecorationColor: getThemeColor(theme.colors, props.textDecorColor || props.textDecorationColor),
    textShadowColor: getThemeColor(theme.colors, props.textShadowColor),
    ...((_props$textShadowOffs = props.textShadowOffset) !== null && _props$textShadowOffs !== void 0 && _props$textShadowOffs.width || (_props$textShadowOffs2 = props.textShadowOffset) !== null && _props$textShadowOffs2 !== void 0 && _props$textShadowOffs2.height ? {
      textShadowOffset: {
        width: (_props$textShadowOffs3 = props.textShadowOffset) === null || _props$textShadowOffs3 === void 0 ? void 0 : _props$textShadowOffs3.width,
        height: (_props$textShadowOffs4 = props.textShadowOffset) === null || _props$textShadowOffs4 === void 0 ? void 0 : _props$textShadowOffs4.height
      }
    } : {}),
    textShadowRadius: getThemeProperty(theme.borderRadius, props.textShadowRadius),
    fontWeight: getFontWeight(theme.fontFamily, props.fontFamily, props.fontWeight),
    fontFamily: props.fontFamily ?? getThemeFontFamily(theme.fontFamily, props.fontWeight),
    ...createBorderWidthStyles(props),
    ...createSpacingStyles(props, theme.spacing),
    ...createBorderColorStyles(props, theme.colors),
    ...createBorderRadiusStyles(props, theme.borderRadius)
  };

  // merging style props to computed style
  if (props.style) {
    computedStyle.text = {
      ...computedStyle.text,
      // @ts-ignore
      ...props.style
    };
  }
  return StyleSheet.create(computedStyle);
};
//# sourceMappingURL=text.style.js.map